@@ -88,11 +88,12 @@ class FaceDetectionStub(Stub):
             content={}
         )
 
-    def to_recognize(self, detected_object_class_id:int) -> None:
+    def to_recognize(self, detected_object_class_id:int, image_key:str) -> None:
         self._send(
             primitive='to_recognize',  
             content={
-                'detected_object_class_id': detected_object_class_id
+                'detected_object_class_id': detected_object_class_id,
+                'image_key': image_key
             }
         )
 
@@ -108,10 +109,11 @@ class VehicleDirectionDetectionStub(Stub):
             content={}
         )
 
-    def to_predict(self, detected_object_class_id:int) -> None:
+    def to_predict(self, detected_object_class_id:int, image_key:str) -> None:
         self._send(
             primitive='to_predict',  
             content={
-                'detected_object_class_id': detected_object_class_id
+                'detected_object_class_id': detected_object_class_id,
+                'image_key': image_key
             }
         )
\ No newline at end of file
